@@ -1,5 +1,6 @@
 from pythontools.core import logger
 from threading import Thread
+import traceback
 
 class Event:
 
@@ -31,4 +32,5 @@ def call(name, *args, scope="global", **kwargs):
             if event.name == name and event.scope == scope:
                 event.call(*args, **kwargs)
     except Exception as e:
-        logger.log("§cEvent '" + name + "' throw exception: " + str(e))
\ No newline at end of file
+        logger.log("§cEvent '" + name + "' throw exception: " + str(e))
+        traceback.print_exc()
\ No newline at end of file
