@@ -1,9 +1,20 @@
 import random, json, os, shutil
 
-def getFileContent(path):
-    with open(path, 'r', encoding='utf-8') as file:
-        content = file.readlines()
-    return [line.replace("\n", "").replace("\r", "") for line in content]
+def getFileContent(path, asBytes=False, asLines=True):
+    if asBytes is True:
+        with open(path, 'rb') as file:
+            content = file.read()
+        return content
+    else:
+        with open(path, 'r', encoding='utf-8') as file:
+            if asLines is True:
+                content = file.readlines()
+            else:
+                content = file.read()
+        if asLines is True:
+            return [line.replace("\n", "").replace("\r", "") for line in content]
+        else:
+            return content
 
 def getLineFromFile(path, line):
     content = getFileContent(path)
@@ -19,9 +30,13 @@ def appendToFile(path, text, nextLine=False):
     with open(path, 'a', encoding='utf-8') as file:
         file.write(text + "\n" if nextLine else "")
 
-def writeToFile(path, text, nextLine=False):
-    with open(path, 'w', encoding='utf-8') as file:
-        file.write(text + "\n" if nextLine else "")
+def writeToFile(path, content):
+    if type(content) is bytes:
+        with open(path, 'wb') as file:
+            file.write(content)
+    else:
+        with open(path, 'w', encoding='utf-8') as file:
+            file.write(content)
 
 def createFile(path):
     file = open(path, "w", encoding='utf-8')
